Tutorials
=========

This section contains tutorials that teach the use of pyLife and its
principles.  As opposed to the :doc:`/cookbook` it does not show actual
workflows.  The notebook files are available in the ``/demos`` `directory
<https://github.com/boschresearch/pylife/tree/develop/demos>`_ of
pyLife's codebase.

If you want to try out the notebooks without installing anything on your
computer, you can use `MyBinder
<https://mybinder.org/v2/gh/boschresearch/pylife/develop?labpath=demos%2Findex.ipynb>`_.


.. toctree::
   :maxdepth: 1

   demos/woehler_curve.nblink
   demos/load_collective.nblink
   demos/stress_strength.nblink
